$title	Static General Equilibrium Model for Columbia -- based on the 1996 SAM

option mcp=pathold;

$ontext
A General Equilibrium Model for Columbia
based on the 1996 Social Accounting Matrix

Economics Research
National Department of Planning
Calle 26, No 13-19, Piso 18
Bogot, Colombia

This is a pilot version of the model used to compute the marginal
cost of funds from alternative tax instruments.  The model includes
formal and informal labor, resource-based production sectors, imports
and exports.  The model may be run with horizon=static or
horizon=steady.  In the static model the aggregate capital stock is
fixed.  In the steady-state model, the capital stock is assumed to
adjust such that the rate of return to capital exactly covers
interest plus depreciation (Tobin's q=1).

Thomas F. Rutherford

Version 0
November 27, 2001

$offtext


$if not set resource $set resource 1
$if not set etrndx   $set etrndx   2
$if not set etrnl    $set etrnl    0
$if not set esubdm   $set esubdm   4
$if not set esubkl   $set esubkl   1
$if not set horizon  $set horizon static

set r	SAM rows /1*37/;  

alias (r,c);

set	s	Sectors /
cof	Coffee
cro	Other crops
lvs	Livestock
ffh	Forestry fishing and hunting
oil	Oil
min	Other Minerals
thr	Coffee Threshing
fod	Foodstuffs
nri	Natural Resources Intensive Industries
nsi	Non-skilled Labor Intensive Industries
htc	Capital and High Technology Industries
con	Construction
trn	Transport 
ele	Electricity Gas and Water
com	Communications
ser	Private Services
gov	Government Services /;

set map(*,r)	Mapping onto the SAM rows /
cof.1	Coffee
cro.3	Other crops
lvs.4	Livestock
ffh.5	Forestry fishing and hunting
oil.6	Oil
min.7	Other Minerals
thr.2	Coffee Threshing
fod.8	Foodstuffs
nri.9	Natural Resources Intensive Industries
nsi.10	Non-skilled Labor Intensive Industries
htc.11	Capital and High Technology Industries
con.12	Construction
trn.13	Transport 
ele.14	Electricity Gas and Water,
com.15	Communications
ser.16	Private Services
gov.17	Government Services /;

$include sam.dat

parameter	samchk	Check of SAM consistency;
samchk(r) = round(sum(c, sam(r,c)-sam(c,r)), 5);
display samchk;

*	Do some scaling:

sam(r,c) = sam(r,c)/1000;

alias (s,ss);

set	l	Labor types /formal, informal/,
	k	Capital types /public, private/,
	m	Margin types /trade, commerce/;

parameter	
	d0(s)		Domestic supply
	x0(s)		Exports
	ty(s)		Indirect tax rate
	id0(s,ss)	Intermediate demand,
	rd0(s)		Sector-specific resource rents (net tax)
	ld0(l,s)	Sectoral wage earnings (net of tax)
	rk0(k,s)	Capital earnings (net of tax)
	vat(s)		Value-added tax rate
	pk0(k,s)	Reference price of capital
	pl0(l,s)	Reference wage rates
	tk(k)		Capital tax rate (direct tax)
	tl(l)		Labor tax rate (direct tax)

	a0(s)		Armington supply
	ms0(m,s)	Margin supply
	md0(m,s)	Margin demand
	m0(s)		Sectoral imports
	tm(s)		Import tariff rate
	pm0(s)		Refernce price of imports

	i0(s)		Investment demand

	g0(s)		Government demand
	govtinv		Government net investment demand
	govtk(k)	Government capital earnings
	govttrn		Government transfer income

	c0(s)		Household consumption demand
	hhinv		Household investment demand
	hhk(k)		Household capital earnings (net)
	hhtrn		Household transfer income
	ls0(l)		Household labor supply

	vatrev		VAT revenue by sector
	indtax		Indirect tax payments by sector (ex VAT)
	wagetax		Direct taxes on formal labor
	capitaltax	Direct taxes on capital earnings;

loop((s,ss,r,c)$(map(s,r)*map(ss,c)), id0(s,ss) = sam(r,c); sam(r,c) = 0;);

loop((s,c)$map(s,c), 

*	Extract components of final demand:

	c0(s) = sam(c,"29"); sam(c,"29") = 0;
	g0(s) = sam(c,"30"); sam(c,"30") = 0;
	x0(s) = sam(c,"33"); sam(c,"33") = 0;
	i0(s) = sam(c,"35")+sam(c,"36")+sam(c,"37");
	sam(c,"35")=0; sam(c,"36")=0; sam(c,"37")=0;

*	Extract margin supply and demand:

	md0("trade",s) = max(0, sam("25",c));
	ms0("trade",s) = max(0, -sam("25",c));
	sam("25",c) = 0;

	md0("commerce",s) = max(0, sam("24",c));
	ms0("commerce",s) = max(0, -sam("24",c));
	sam("24",c) = 0;

*	Extract tax revenue:

	vatrev(s) = sam("22",c); sam("22",c) = 0;
	indtax(s) = sam("21",c)+sam("26",c)+sam("27",c);
	sam("21",c)=0;sam("26",c)=0;sam("27",c)=0;

*	Imports and tariff rates:

	m0(s) = sam("33",c); sam("33",c) = 0;
	tm(s)$m0(s) = sam("23",c)/m0(s); sam("23",c) = 0;
	pm0(s) = 1 + tm(s);

*	Save direct tax payments for computing tl and tk:

	wagetax = sam("28","29");
	capitaltax = sam("28","32");

*	Initially store labor earnings gross of direct taxes:

	ld0("formal",s) = sam("18",c); sam("18",c) = 0;
	ld0("informal",s) = sam("19",c); sam("19",c) = 0;

*	Initially store all capital earnings as returns to private capital:

	rk0("private",s) = sam("20",c); sam("20",c)=0;

);

*	Compute tax rates:

tl("formal") = wagetax / (sum(s, ld0("formal",s))-wagetax);
ld0(l,s) = ld0(l,s) / (1+tl(l));

rk0("public","gov") = rk0("private","gov");
rk0("private","gov") = 0;
tk("private") = capitaltax / (sum(s, rk0("private",s))-capitaltax);
rk0(k,s) = rk0(k,s) / (1 + tk(k));
vat(s) = vatrev(s) / (sum(l,ld0(l,s))+sum(k,rk0(k,s)));

parameter	rshare(s)	Resource share of capital income /

*	NB  -- These values are arbitrarily chosen.

	cof	0.25,
	cro	0.25,
	lvs	0.25,
	ffh	0.25,
	oil	0.75,
	min	0.75,
	nri	0.50,
	thr	0,
	fod	0,
	nsi	0,
	htc	0,
	con	0,
	trn	0,
	ele	0,
	com	0,
	ser	0,
	gov	0 /;
	
rd0(s) = %resource% * rshare(s) * sum(k, rk0(k,s));
rk0(k,s) = (1- %resource% * rshare(s)) * rk0(k,s);
pl0(l,s) = 1 + vat(s) + tl(l);
pk0(k,s) = 1 + vat(s) + tk(k);

d0(s) = sum(ss, id0(ss,s)) 
	+ rd0(s)*pk0("private",s)
	+ sum(l, ld0(l,s)*pl0(l,s)) 
	+ sum(k, rk0(k,s)*pk0(k,s))
	- x0(s) + indtax(s);
ty(s) = indtax(s) / (d0(s) + x0(s));

parameter mktchk	Cross check of consistency;

a0(s) = d0(s) + m0(s)*pm0(s) + sum(m, md0(m,s)-ms0(m,s));
mktchk(s) = a0(s) - sum(ss, id0(s,ss)) - c0(s) - i0(s) - g0(s);
display mktchk;

govtk("public") = sum(s, rk0("public",s));
hhk("private") = sum(s, rk0("private",s));
govtinv = sam("36","30");
hhinv = sum(s, i0(s)) - govtinv;

*	Labor supply equals labor demand:

ls0(l) = sum(s, ld0(l,s));

*	Government transfer level determined as a residual:

govttrn = sum(s, g0(s)) + govtinv - sum(k, govtk(k))
	- sum(s, ty(s)*(d0(s)+x0(s))) 
	- sum(s,         rd0(s)*(vat(s)+tk("private"))
		+ sum(l, ld0(l,s)*(vat(s)+tl(l)))
		+ sum(k, rk0(k,s)*(vat(s)+tk(k)))
		+ tm(s)*m0(s));

*	Household transfer level determined as a residual:

hhtrn = sum(s, c0(s)) + hhinv 
	- sum(k, hhk(k)) - sum(l, ls0(l)) - sum(s, rd0(s));

scalar	glvl	Level of public expenditure /1/;

set	ti	Tax instruments / vat, ty, tm, tl, tk /;

$ontext

$model:static

$sectors:
	y(s)	! Domestic production
	a(s)	! Aggregate supply
	inv	! Investment
	cl	! Consumption level
	ls	! Labor supply

$commodities:
	pd(s)	! Domestic output price
	p(s)	! Armington aggregate price
	rk(k)	! Capital return by capital type
	pm(m)	! Trade and transport margins
	pfx	! Foreign exchange
	pinv	! Aggregate investment
	w(l)	! Wage rates (formal and informal)
	pc	! Consumption price index
	pr(s)$rd0(s)	! Return to industry-specific fixed factors
	wage	! Aggregate wage rate

$consumers:
	hh	! Households
	govt	! Government

$auxiliary:
	tau(ti)	! Tax multipliers
	kstock	! Capital stock

*	Taxes applied on production include:

*	ty:	Indirect taxes
*	vat:	Value-added taxes
*	tk:	Direct taxes on capital earnings
*	tl:	Direct taxes on labor earnings

$prod:y(s)  s:0  t:%etrndx% va:%esubkl%
	o:pd(s)	q:d0(s)		a:govt n:tau("ty") m:ty(s)
	o:pfx	q:x0(s)		a:govt n:tau("ty") m:ty(s)
	i:p(ss)	q:id0(ss,s)
	i:pr(s)	q:rd0(s)	a:govt n:tau("vat") m:vat(s) n:tau("tk") m:tk("private") p:pk0("private",s) va:
	i:w(l)	q:ld0(l,s)	a:govt n:tau("vat") m:vat(s) n:tau("tl") m:tl(l) p:pl0(l,s) va:
	i:rk(k)	q:rk0(k,s)	a:govt n:tau("vat") m:vat(s) n:tau("tk") m:tk(k) p:pk0(k,s) va:

*	Aggregate supply activity incorporates imports, tariffs, and
*	net transportation and commercial margins:

$prod:a(s)  s:0 t:0 dm:%esubdm%
	o:p(s)	q:a0(s)
	o:pm(m)	q:ms0(m,s)
	i:pm(m)	q:md0(m,s)
	i:pfx	q:m0(s)	a:govt  n:tau("tm") m:tm(s)  p:pm0(s)	dm:
	i:pd(s)	q:d0(s)						dm:

*	Investment is aggregated to a single sector:

$prod:inv
	o:pinv	q:(sum(s,i0(s)))
	i:p(s)	q:i0(s)

*	Households buy goods and undertake investments using 
*	labor income, sector-specific resources, capital income,
*	and net transfers:

$demand:hh  
	d:pc		q:(sum(s,c0(s)))
	e:pinv		q:(-hhinv)	r:kstock
	e:rk(k)		q:hhk(k)	r:kstock
	e:pfx		q:hhtrn
	e:wage		q:(sum(l,ls0(l)))
	e:pr(s)		q:rd0(s)

$prod:cl  s:1
	o:pc		q:(sum(s, c0(s)))
	i:p(s)		q:c0(s)

$prod:ls  t:%etrnl%
	o:w(l)		q:ls0(l)
	i:wage		q:(sum(l,ls0(l)))


*	Government spends money on the purchase of government 
*	services and investment.  The government earns tax revenue, 
*	capital rents, and net transfers:

$demand:govt
	d:p(s)		q:g0(s)
	e:pinv		q:(-govtinv)	r:kstock
	e:rk(k)		q:govtk(k)	r:kstock
	e:pfx		q:govttrn

$constraint:kstock
	pinv =e= rk("private");

$constraint:tau(ti)
	y("gov") =e= glvl;


$offtext
$sysinclude mpsgeset static

parameter	taxrates	Base year tax rates;

taxrates(s,"tm") = round(100 * tm(s));
taxrates(s,"ty") = round(100 * ty(s));
taxrates(s,"vat") = round(100 * vat(s));
option taxrates:0;
display taxrates, tl, tk;

tau.fx(ti) = 1;
kstock.fx = 1;

parameter	revenue	Tax revenue by instrument
		report	Summary report on cost of public revenue;

revenue("ty") = sum(s, ty(s)*(d0(s)+x0(s)));
revenue("tk") = sum(s, sum(k, tk(k)*rk0(k,s)) + tk("private")*rd0(s));
revenue("vat") = sum(s, (rd0(s)+sum(l,ld0(l,s))+sum(k,rk0(k,s)))*vat(s));
revenue("tl") = sum(s, sum(l,ld0(l,s)*tl(l)));
revenue("tm") = sum(s, m0(s)*tm(s));
display revenue;


parameter	echop	Echo print for the dataset;

echop(s,"xvshr") = round(100*x0(s)/(x0(s)+d0(s)));
echop(s,"labshr")= round(100*sum(l, ld0(l,s)*pl0(l,s))/
	(sum(l, ld0(l,s)*pl0(l,s))+sum(k,rk0(k,s)*pk0(k,s))+rd0(s)*pk0("private",s)));
echop(s,"mvshr") = round(100*m0(s)*pm0(s)/(m0(s)*pm0(s)+d0(s)));
echop(s,"fvshr") = round(100*ld0("formal",s)*pl0("formal",s)/
		   sum(l,ld0(l,s)*pl0(l,s)));
parameter gdp;
gdp(s) = rd0(s)+sum(l,ld0(l,s))+sum(k,rk0(k,s));

echop(s,"gdpshr") = round(100 * gdp(s) / sum(ss, gdp(ss)));
option echop:0;
display echop;

*	Check the benchmark equilibrium:

static.iterlim = 0;
$include static.gen
solve static using mcp;
static.iterlim = 8000;

*	Set up the calculation:

$if %horizon%==steady  kstock.lo = 0;  kstock.up = +inf;

alias (ti,taxinst);

parameter
	tolerance	Solution tolerance
	results		Summary results;

loop(taxinst,

	tau.fx(taxinst) = 1.1;

$include static.gen
	solve static using mcp;

	tolerance(taxinst) = static.objval;

	results(taxinst,"yield") = 100 *
		(y.l("gov")-1)*(d0("gov")+x0("gov"))/(0.1*revenue(taxinst));

	results(taxinst,"mcf")$(y.l("gov")-1) = ((1-cl.l)*sum(s,c0(s))/
		((y.l("gov")-1)*(d0("gov")+x0("gov"))));

	results(taxinst,"mcf_k")$(y.l("gov")-1) = (rk.l("private")/pc.l-1) / (y.l("gov")-1);

	results(taxinst,"mcf_fl")$(y.l("gov")-1) = (w.l("formal")/pc.l-1) / (y.l("gov")-1);

	results(taxinst,"mcf_il")$(y.l("gov")-1) = (w.l("informal")/pc.l-1) / (y.l("gov")-1);

	results(taxinst,"kstock") = 100 * (kstock.l-1);

	tau.fx(taxinst) = 1;

);

display results;

